
## Release Notes

**v0.4.1 - September 20, 2023**

* adding LICENSE to manifest

**v0.4.0 - September 19, 2023**

* CL-utils clean up
* Code ready to be released into the wild
* Doc updates

**v0.3.1 - May 11, 2022**

* Doc fixes

**v0.3.0 - May 19, 2020**

* Now compatible with Python 3.*
